#include <stdio.h>
#include <unistd.h>

#include "str_tools.h"

void usage (char *progname);

/*
 ------------------------------------------------------------------------
 main function checks parameters and performs requested action
 ------------------------------------------------------------------------ */
int main (int argc, char *argv[])
{
    char *newname;

    // check for number of arguments
    if (argc != 2)
    {
        usage (argv[0]);
        return 1;
    }

    // check for existence of file being renamed
    if (access (argv[1], F_OK) != 0)
    {
        printf ("file `%s' does not exist\n", argv[1]);
        return 1;
    }

    // convert the name
    newname = str_shorten (argv[1]);
    if (newname == NULL)
    {
        printf ("cannot convert `%s' to 8+3 scheme\n", argv[1]);
        return 1;
    }

    // check whether it was already 8+3
    if (strcmp (argv[1], newname) == 0)
    {
        printf ("the file name `%s' is already in 8+3 format\n", argv[1]);
        return 1;
    }
    
    // check whether it already exists
    if (access (newname, F_OK) == 0)
    {
        printf ("the file `%s' already exists\n", newname);
        return 1;
    }

    // rename file
    if (rename (argv[1], newname) < 0)
    {
        printf ("error renaming `%s' to `%s'; ", argv[1], newname);
        perror ("reason is");
        return 1;
    }

    printf ("file `%s' has been renamed to `%s'\n", argv[1], newname);
    return 0;
}
/*
 -----------------------------------------------------------------------
 usage tells how to invoke program
 ----------------------------------------------------------------------- */
void usage (char *progname)
{
    printf ("\n"
            "Fertilizer version 0.90  Copyright (C) 1998 Sergey Ayukov\n"
            "Reduces long filenames to 8+3 (FAT) scheme.\n"
            "\n"
            "Usage: %s <filename>\n"
            "  where <filename> is the name of the file to be renamed to 8+3 scheme\n", progname);
}
